# PsychoAnalyze

Interactive data simulation and analysis for psychophysics.


![PyPI - Python Version](https://img.shields.io/pypi/pyversions/psychoanalyze)
![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)
[![security: bandit](https://img.shields.io/badge/security-bandit-yellow.svg)](https://github.com/PyCQA/bandit)
[![Open in Remote - Containers](https://img.shields.io/static/v1?label=Remote%20-%20Containers&message=Open&color=blue&logo=visualstudiocode)](https://vscode.dev/redirect?url=vscode://ms-vscode-remote.remote-containers/cloneInVolume?url=https://github.com/psychoanalyze/psychoanalyze)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/psychoanalyze/psychoanalyze/main.svg)](https://results.pre-commit.ci/latest/github/psychoanalyze/psychoanalyze/main)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/psychoanalyze/psychoanalyze/main?labpath=docs%2Fnotebooks%2Ftutorial.ipynb)


## Dashboard
See what `psychoanalyze` can do by [viewing our dashboard](https://psychoanalyze.io/).

## Install with Python
```console
pip install psychoanalyze

psychoanalyze --help
```
## Documentation
View the full documentation at [https://docs.psychoanalyze.io](https://docs.psychoanalyze.io).
